Documentation
¶
Overview ¶
Package reporter wrapper abstracting Sentry.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrReporterInitializationFail = errors.New("reporter init error")
ErrReporterInitializationFail indicates an error with the report initialization parameters.
Functions ¶
func Initialize ¶
Initialize and configures underlying Sentry library.
Types ¶
type EventID ¶
EventID is a hexadecimal string representing a unique uuid4 for an Event. An EventID must be 32 characters long, lowercase and not have any dashes.
func CaptureException ¶
CaptureException captures an error.
Click to show internal directories.
Click to hide internal directories.